@@ -1,4 +1,3 @@
-import locale
 import warnings
 import os
 import struct
@@ -13,11 +12,16 @@ from itertools import chain
 import _dbdreader
 import logging
 
-# make sure we interpret timestamps in the english language
-locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
+# make sure we interpret timestamps in the english language but don't
+# bother if it cannot be import as happens on building doc on readthe
+# docs
+try:
+    import locale
+    locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
+except:
+    pass
 
 logger = logging.getLogger(os.path.basename(__file__))
-logging.basicConfig(level=logging.INFO)
 
 LATLON_PARAMS = ["m_lat",
                  "m_lon",
@@ -53,7 +57,7 @@ LATLON_PARAMS = ["m_lat",
 def strptimeToEpoch(datestr, fmt):
     ''' Converts datestr into seconds
 
-    Function to convert a date string into seconds since Epoch. 
+    Function to convert a date string into seconds since Epoch.
     This function is not affected by the time zone used by the OS and
     interprets the date string in UTC.
 
@@ -65,7 +69,7 @@ def strptimeToEpoch(datestr, fmt):
 
     fmt: str
         Format to interpret strings. Example: "%Y %b %d"
-    
+
     Returns
     -------
     int
@@ -77,7 +81,7 @@ def strptimeToEpoch(datestr, fmt):
 
 def epochToDateTimeStr(seconds,dateformat="%Y%m%d",timeformat="%H:%M"):
     ''' Converts seconds since Epoch to date string
-    
+
     This function converts seconds since Epoch to a datestr and timestr
     with user configurable formats.
 
@@ -117,7 +121,7 @@ def toDec(x,y=None):
     ----------
     x: float
         latitiude or longitude in NMEA format
-    y: float, optional 
+    y: float, optional
        latitiude or longitude in NMEA format
 
     Returns
@@ -145,6 +149,7 @@ if not os.path.exists(CACHEDIR):
     os.makedirs(CACHEDIR)
 
 
+
 DBD_ERROR_CACHE_NOT_FOUND=1
 DBD_ERROR_NO_VALID_PARAMETERS=2
 DBD_ERROR_NO_TIME_VARIABLE=3
@@ -153,6 +158,10 @@ DBD_ERROR_NO_FILES_FOUND=5
 DBD_ERROR_NO_DATA_TO_INTERPOLATE_TO=6
 DBD_ERROR_CACHEDIR_NOT_FOUND=7
 DBD_ERROR_ALL_FILES_BANNED=8
+DBD_ERROR_INVALID_DBD_FILE = 9
+DBD_ERROR_INVALID_ENCODING = 10
+DBD_ERROR_INVALID_FILE_CRITERION_SPECIFIED = 11
+
 
 class DbdError(Exception):
     def __init__(self,value=9,mesg=None):
@@ -176,13 +185,19 @@ class DbdError(Exception):
             mesg='Cache file directory does not exist.'
         elif self.value==DBD_ERROR_ALL_FILES_BANNED:
             mesg='All data files were banned.'
+        elif self.value==DBD_ERROR_INVALID_DBD_FILE:
+            mesg='Invalid DBD file.'
+        elif self.value==DBD_ERROR_INVALID_ENCODING:
+            mesg='Invalid encoding version encountered.'
+        elif self.value==DBD_ERROR_INVALID_FILE_CRITERION_SPECIFIED:
+            mesg='Invalid or conflicting file selection criterion/criteria specified.'
         else:
-            mesg='Undefined error.'
+            mesg=f'Undefined error. ({self.value})'
         if self.mesg:
-            mesg+=self.mesg
+            mesg = " ".join((mesg, self.mesg))
         return mesg
 
-    
+
 '''
 
 how the sbd files work (and presumably the other files as well)
@@ -213,7 +228,7 @@ class DBD:
         init (opens a file)
         close(closes a file)
         get(param)  (returns time and data for given variable)
-        
+
     private methods:
         read_header
         read_sensor_list
@@ -224,8 +239,8 @@ class DBD:
 
 class DBDList(list):
     ''' List that properly sorts dbd files.
-    
-    Object subclassed from list. The sort method defaults to sorting dbd 
+
+    Object subclassed from list. The sort method defaults to sorting dbd
     files and friends in the right order.
 
     Parameters
@@ -237,17 +252,17 @@ class DBDList(list):
         list.__init__(self,*p)
 
     def __keyFilename(self,x):
-        xx=re.sub("\.[demnst]bd","",os.path.basename(x))
+        xx=re.sub("\.[demnstDEMNST][bB][dD]","",os.path.basename(x))
         if "-" in xx:
             xxx=xx.split("-")
             n=sum([int(i)*10**j for i,j in zip(xxx[1:],[8,5,3,0])])
             return xxx[0]+"%d"%(n)
         else:
             return xx
-                             
+
     def sort(self,cmp=None, key=None, reverse=False):
         ''' sorts filenames ensuring dbd files are in chronological order in place
-        
+
         Parameters
         ----------
         cmp :
@@ -269,18 +284,18 @@ class DBDPatternSelect(object):
     ----------
     date_format : str, optional
          date format used to interpret date strings.
-    
+
     Note
     ----
         Times are based on the opening time of the file only.
 
     '''
     cache = {}
-    
+
     def __init__(self, date_format="%d %m %Y"):
         self.set_date_format(date_format)
 
-        
+
     def set_date_format(self,date_format):
         ''' Set date format
 
@@ -290,13 +305,13 @@ class DBDPatternSelect(object):
         ----------
         date_format: str
             format to interpret date strings. Example "%H %d %m %Y"
-        
+
         '''
         self.date_format=date_format
 
     def get_date_format(self):
         ''' Returns date format string.
-        
+
         Returns
         -------
         str:
@@ -308,25 +323,25 @@ class DBDPatternSelect(object):
     def select(self,pattern=None,filenames=[],from_date=None,until_date=None):
         '''Select file names from pattern or list.
 
-        This method selects the filenames given a filename list or search 
+        This method selects the filenames given a filename list or search
         pattern and given time limits.
 
         Parameters
         ----------
         pattern: str
             search pattern (passed to glob) to find filenames
-        
+
         filenames: list of str
             filename list
-        
+
         from_date: None or str, optional
             date used as start date criterion. If None, all files are
             included until the until_date.
 
         until_date: None or str, optional
-            date used aas end date criterion. If None, all files after 
+            date used aas end date criterion. If None, all files after
             from_date are included.
-        
+
         Returns:
              list of filenames that match the criteria
 
@@ -335,13 +350,13 @@ class DBDPatternSelect(object):
 
         Note
         ----
-        Either pattern or filenames should be supplied, and at least one of 
+        Either pattern or filenames should be supplied, and at least one of
         from_date and until_date.
 
         '''
 
         all_filenames = self.get_filenames(pattern, filenames)
-        
+
         if not from_date and not until_date:
             # just get all files.
             t0=t1=None
@@ -374,10 +389,10 @@ class DBDPatternSelect(object):
         ----------
         pattern: str
             search pattern (as used in glob)
-        
+
         filenames: list of str
             filename list
-        
+
         binsize: float
             binsize of in seconds
 
@@ -409,17 +424,17 @@ class DBDPatternSelect(object):
                 for left, right in zip(bin_edges[0:-1], bin_edges[1:])]
         return bins
 
-        
+
     def get_filenames(self, pattern, filenames, cacheDir=None):
         ''' Get filenames (sorted) and update CAC cache directory.
-        
+
         Parameters
         ----------
         pattern : str
             search pattern (as used in glob)
         filenames : list of str
             list of filenames
-        
+
         Returns
         -------
         list of str
@@ -436,7 +451,7 @@ class DBDPatternSelect(object):
         all_filenames.sort()
         self.__update_cache(all_filenames, cacheDir)
         return all_filenames
-    
+
     def __update_cache(self, fns, cacheDir):
         cached_filenames = DBDList(self.cache.values())
         cached_filenames.sort()
@@ -445,7 +460,7 @@ class DBDPatternSelect(object):
                 dbd=DBD(fn, cacheDir)
                 t_open=dbd.get_fileopen_time()
                 self.cache[t_open]=fn
-                
+
     def __select(self,all_fns,t0,t1):
         open_times = numpy.array(list(self.cache.keys()))
         open_times = numpy.sort(open_times)
@@ -456,11 +471,11 @@ class DBDPatternSelect(object):
         fns.sort()
         return fns
 
-            
-                                                          
-            
-        
-        
+
+
+
+
+
 class DBDHeader(object):
 
     ''' Class to read the headers of DBD files. This file is typically used
@@ -480,22 +495,30 @@ class DBDHeader(object):
                        'full_filename':'string',
                        'the8x3_filename':'string'}
         self.info={}
-        
-    def read_header(self,fp):
+
+    @property
+    def factored(self):
+        try:
+            r = self.info['sensor_list_factored']
+        except KeyError:
+            r = None
+        return r
+    
+    def read_header(self, fp, filename=''):
         ''' read the header of the file, given by fp '''
         fp.seek(0)
         if not self.parse(fp.readline())=='dbd_label':
-            raise ValueError("Seems not to be a valid DBD file")
+            return DBD_ERROR_INVALID_DBD_FILE
         n_read=1
-        while 1:
+        while True:
             self.parse(fp.readline())
             n_read+=1
             if 'num_ascii_tags' in self.info  and \
                self.info['num_ascii_tags']==n_read:
                 break
         if self.info['encoding_ver']!=ENCODING_VER:
-            raise ValueErro('Incompatible encoding version detected.')
-        return self.info['sensor_list_factored']
+            return DBD_ERROR_INVALID_ENCODING
+        return 0
 
     def read_cache(self,fp, fpcopy=None):
         ''' read cache file '''
@@ -527,13 +550,13 @@ class DBDHeader(object):
                 self.info[param]=value
         return param
 
-        
+
 class DBD(object):
-    ''' Class to read a single DBD type file 
+    ''' Class to read a single DBD type file
 
     Parameters
     ----------
-    
+
     filename: str
         dbd filename
 
@@ -544,12 +567,13 @@ class DBD(object):
     def __init__(self,filename,cacheDir=None, raise_exception_if_cac_not_found=True):
 
         self.filename=filename
-        self.fp=open(filename,'br')
+        logger.debug('Opening %s', filename)
         if cacheDir==None:
             self.cacheDir=CACHEDIR
         else:
             self.cacheDir=cacheDir
-        self.headerInfo,parameterInfo,self.cacheFound, self.cacheID = self.__read_header(self.cacheDir)
+        with open(filename,'br') as self.fp:
+            self.headerInfo,parameterInfo,self.cacheFound, self.cacheID = self.__read_header(self.cacheDir)
         # number of bytes each states section consists of:
         self.n_state_bytes=self.headerInfo['state_bytes_per_cycle']
         # size of variables used
@@ -558,7 +582,6 @@ class DBD(object):
         self.parameterNames=[i[1] for i in parameterInfo]
         self.parameterUnits=dict((i[1],i[2]) for i in parameterInfo)
         self.timeVariable=self.__set_timeVariable()
-        self.close()
         if not self.cacheFound and raise_exception_if_cac_not_found:
             raise DbdError(DBD_ERROR_CACHE_NOT_FOUND, f" ({self.cacheID}.cac)")
 
@@ -568,7 +591,7 @@ class DBD(object):
     #     self.ti = ti
     #     self.vi =vi
     #     return self.__get_by_read_per_byte(parameter)
-    
+
     def get_mission_name(self):
         ''' Returns the mission name such as micro.mi '''
         return self.headerInfo['mission_name'].lower()
@@ -582,8 +605,8 @@ class DBD(object):
         return self.fp.close()
 
     def get(self,*parameters,decimalLatLon=True,discardBadLatLon=True, return_nans=False):
-        '''Returns time and parameter data for requested parameter 
-        
+        '''Returns time and parameter data for requested parameter
+
         This method reads the requested parameter, and convert it
         optionally to decimal format if the parameter is latitude-like
         or longitude-like
@@ -594,12 +617,12 @@ class DBD(object):
             parameter name
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         return_nans : bool, optional
             if True, nans are returned for timestamps the variable was not updated or changed.
 
@@ -618,7 +641,7 @@ class DBD(object):
         timestamps, values =  self._get(*parameters, decimalLatLon=decimalLatLon,
                                         discardBadLatLon=discardBadLatLon, return_nans=return_nans)
         r = [(t,v) for t, v in zip(timestamps, values)]
-        
+
         if len(parameters)==1:
             return r[0]
         else:
@@ -627,11 +650,11 @@ class DBD(object):
     def get_list(self,*parameters,decimalLatLon=True,discardBadLatLon=True,
                  return_nans=False):
         ''' Returns time and value tuples for a list of requested parameters
-        
+
 
         This method returns time and values tuples for a list of parameters. It
         is basically a short-hand for a looped get() method.
-        
+
         Note that each parameter comes with its own time base. No interpolation
         is done. Use get_sync() for that in stead.
 
@@ -641,34 +664,34 @@ class DBD(object):
             list of parameter names
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         return_nans : bool
             If True, nan's are returned for those timestamps where no new value is available.
             Default value: False
 
         Returns
         -------
-        list of (ndarray, ndarray) 
+        list of (ndarray, ndarray)
             list of tuples of time and value vectors for each parameter requested.
 
         .. deprecated:: 0.4.0
-            
+
         .. note::
             This function will be removed in a future version. Use .get() instead.
         '''
         logger.info("get_list has been deprecated in version 0.4.0 and may be removed in the future. Use get instead.")
         return self.get(*parameters,decimalLatLon=decimalLatLon ,discardBadLatLon=discardBadLatLon , return_nans=return_nans)
-        
+
     def get_xy(self,parameter_x,parameter_y,decimalLatLon=True, discardBadLatLon=True):
         ''' Returns values of parameter_x and paramter_y
 
-        For parameters parameter_x and parameter_y this method returns a tuple 
-        with the values of both parameters. If necessary, the time base of 
+        For parameters parameter_x and parameter_y this method returns a tuple
+        with the values of both parameters. If necessary, the time base of
         parameter_y is interpolated onto the one of parameter_x.
 
         Parameters
@@ -680,12 +703,12 @@ class DBD(object):
             parameter name of y-parameter
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         Returns
         -------
         (ndarray, ndarray)
@@ -697,10 +720,10 @@ class DBD(object):
 
 
     def get_sync(self, *sync_parameters, decimalLatLon=True, discardBadLatLon=True):
-        '''Returns a list of values from parameters, all interpolated to the 
+        '''Returns a list of values from parameters, all interpolated to the
             time base of the first paremeter
 
-        This method is used if a number of parameters should be interpolated 
+        This method is used if a number of parameters should be interpolated
         onto the same time base.
 
         Parameters
@@ -710,26 +733,26 @@ class DBD(object):
             used to interpolate all other parameters onto.
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         Returns
         -------
         (ndarray, ndarray, ...)
-            Time vector (of first parameter), values of first parmaeter, and 
+            Time vector (of first parameter), values of first parmaeter, and
             interpolated values of subsequent parameters.
 
         Example:
-            
+
             get_sync('m_water_pressure','m_water_cond','m_water_temp')
 
         Notes
         -----
         .. versionchanged:: 0.4.0
-            Calling signature has changed from the sync parameters 
+            Calling signature has changed from the sync parameters
             passed on as a list, to passed on as parameters.
         '''
 
@@ -743,19 +766,19 @@ class DBD(object):
 
     def has_parameter(self,parameter):
         ''' Check wheter this file contains parameter
-        
+
         Parameters
         ----------
         parameter: str
             parameter to check
-        
+
         Returns
         -------
         bool
-            True if parameter is in the list, or False if not 
+            True if parameter is in the list, or False if not
         '''
         return (parameter in self.parameterNames)
-    
+
     # Private methods:
 
     def __get_fileopen_time(self):
@@ -763,7 +786,7 @@ class DBD(object):
         fmt="%a %b %d %H:%M:%S %Y"
         seconds=strptimeToEpoch(datestr, fmt)
         return seconds
-    
+
     def __set_timeVariable(self):
         if 'm_present_time' in self.parameterNames:
             return 'm_present_time'
@@ -811,7 +834,7 @@ class DBD(object):
             if self.__is_latlon_parameter(p):
                 if discardBadLatLon and not return_nans: #discards and return nans is not compatible.
                     # p is either a latitude or longitude parameter. Check now which one it is.
-                    if "lat" in p: 
+                    if "lat" in p:
                         value_limit = 9000 # nmea style
                     else:
                         value_limit = 18000 # nmea style
@@ -836,7 +859,7 @@ class DBD(object):
             to decimal values prior to interpolation.
 
             example:
-            
+
             get_sync('m_water_pressure','m_water_cond','m_water_temp')
         '''
         timestamps, values = self._get(*params,decimalLatLon=decimalLatLon,discardBadLatLon=discardBadLatLon)
@@ -852,7 +875,7 @@ class DBD(object):
             else:
                 r.append(numpy.interp(t, _t, _v, left=numpy.nan, right=numpy.nan))
         return r
-    
+
     def __get_valid_parameters(self,parameters):
         validParameters=[i for i in parameters if i in self.parameterNames]
         return validParameters
@@ -863,14 +886,20 @@ class DBD(object):
     def __read_header(self, cacheDir):
         if not os.path.exists(cacheDir):
             raise DbdError(DBD_ERROR_CACHEDIR_NOT_FOUND, " (%s)"%(cacheDir))
-        dbdheader=DBDHeader()
-        factored=dbdheader.read_header(self.fp)
+        dbdheader = DBDHeader()
+        result = dbdheader.read_header(self.fp)
+        if result == DBD_ERROR_INVALID_DBD_FILE:
+            raise DbdError(DBD_ERROR_INVALID_DBD_FILE,
+                           f"{self.filename} seems not to be a valid DBD file.")
+        elif result == DBD_ERROR_INVALID_ENCODING:
+            raise DbdError(DBD_ERROR_INVALID_ENCODING,
+                           f'{self.filename} has an invalid encoding.')
         # determine cache file name
         cacheID = dbdheader.info['sensor_list_crc'].lower()
         cacheFilename=os.path.join(cacheDir,cacheID+".cac")
         cacheFound=True # unless proven otherwise...
         parameter=[]
-        if factored==1:
+        if dbdheader.factored==1:
             # read sensorlist from cache
             if os.path.exists(cacheFilename):
                 fpCache=open(cacheFilename,'br')
@@ -878,7 +907,7 @@ class DBD(object):
                 fpCache.close()
             else:
                 cacheFound=False
-        else:
+        else: # no need to check for factored==None; the value has been set for sure.
             # read sensorlist from same file and copy
             if not os.path.exists(cacheFilename):
                 # only write, when not existing.
@@ -958,7 +987,7 @@ class DBD(object):
                         R[idx].append(R[idx][-1])
             else:
                 self.fp.seek(fp+chunksize+1)
-            
+
             if fp+chunksize+1>=fp_end:
                 # jumped beyond the end.
                 break
@@ -1020,17 +1049,17 @@ class DBD(object):
 class MultiDBD(object):
     '''Opens multiple dbd files for reading
 
-    
+
     This class is intended for reading multiple dbd files and treating
     them as one.
-    
+
     Parameters
     ----------
     filenames : list of str or None
         list of filenames to open
     pattern : str or None
         search pattern as passed to glob
-    
+
     cacheDir: str or None
         path to directory with CAC cache files (None: the default directory is used)
 
@@ -1063,7 +1092,7 @@ class MultiDBD(object):
     Notes
     -----
     .. versionchanged:: 0.4.0
-        ensure_paired and included_paired keywords have been replaced by complemented_files_only 
+        ensure_paired and included_paired keywords have been replaced by complemented_files_only
         and complement_files, respectively.
     '''
     def __init__(self,filenames=None,pattern=None,cacheDir=None,complemented_files_only=False,
@@ -1075,7 +1104,7 @@ class MultiDBD(object):
         if kwds.get('include_paired', None):
             complement_files = kwds['include_paired']
             logger.info("include_paired keyword is obsolete as of version 0.4.0")
-            
+
         self.__ignore_cache=[]
         if cacheDir is None:
             cacheDir=CACHEDIR
@@ -1085,6 +1114,14 @@ class MultiDBD(object):
         if not filenames and not pattern:
             raise DbdError(DBD_ERROR_NO_FILE_CRITERIUM_SPECIFIED)
         fns=DBDList()
+        # A common mistake is to just supply a string for filenames (first argument)
+        # Assume that it was meant as a pattern IF pattern is None.
+        if isinstance(filenames, str):
+            if pattern is None:
+                pattern = filenames # assume filenames should have been pattern and hope for the best.
+                filenames = None
+            else:
+                raise DbdError(DBD_ERROR_INVALID_FILE_CRITERION_SPECIFIED, "I got a string for <filenames> (no list), and a string for <pattern>.")
         if filenames:
             fns+=filenames
         if pattern:
@@ -1113,13 +1150,13 @@ class MultiDBD(object):
         self.time_limits_dataset=(None,None)
         self.time_limits=[None,None]
         self.set_time_limits()
-    
+
 ##### public methods
     def get(self, *parameters, decimalLatLon=True, discardBadLatLon=True, return_nans=False):
         ''' Returns time and value tuple(s) for requested parameter(s)
-        
+
         This method returns time and values tuples for a list of parameters.
-        
+
         Note that each parameter comes with its own time base. No interpolation
         is done. Use get_sync() for that in stead.
 
@@ -1129,12 +1166,12 @@ class MultiDBD(object):
             list of parameter names
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         return_nans : bool
             If True, nan's are returned for those timestamps where no new value is available.
             Default value: False
@@ -1156,7 +1193,7 @@ class MultiDBD(object):
                 eng_variables.append(p)
         kwds=dict(decimalLatLon=decimalLatLon, discardBadLatLon=discardBadLatLon, return_nans=return_nans)
 
-        if len(sci_variables)>=1: 
+        if len(sci_variables)>=1:
             r_sci = self.__worker("get", "sci", *sci_variables, **kwds)
         if len(eng_variables)>=1:
             r_eng = self.__worker("get", "eng", *eng_variables, **kwds)
@@ -1174,8 +1211,8 @@ class MultiDBD(object):
     def get_xy(self,parameter_x,parameter_y,decimalLatLon=True, discardBadLatLon=True):
         ''' Returns values of parameter_x and paramter_y
 
-        For parameters parameter_x and parameter_y this method returns a tuple 
-        with the values of both parameters. If necessary, the time base of 
+        For parameters parameter_x and parameter_y this method returns a tuple
+        with the values of both parameters. If necessary, the time base of
         parameter_y is interpolated onto the one of parameter_x.
 
         Parameters
@@ -1187,25 +1224,25 @@ class MultiDBD(object):
             parameter name of y-parameter
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         Returns
         -------
         (ndarray, ndarray)
             tuple of value vectors
-        '''    
+        '''
         _, x, y = self.get_sync(parameter_x, parameter_y, decimalLatLon=decimalLatLon, discardBadLatLon=discardBadLatLon)
         return x, y
-    
+
     def get_sync(self,*parameters,decimalLatLon=True, discardBadLatLon=True):
-        ''' Returns a list of values from parameters, all interpolated to the 
+        ''' Returns a list of values from parameters, all interpolated to the
             time base of the first paremeter
 
-        This method is used if a number of parameters should be interpolated 
+        This method is used if a number of parameters should be interpolated
         onto the same time base.
 
         Parameters
@@ -1215,26 +1252,26 @@ class MultiDBD(object):
             used to interpolate all other parameters onto.
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         Returns
         -------
         (ndarray, ndarray, ...)
-            Time vector (of first parameter), values of first parmaeter, and 
+            Time vector (of first parameter), values of first parmaeter, and
             interpolated values of subsequent parameters.
 
         Example:
-            
+
             get_sync('m_water_pressure','m_water_cond','m_water_temp')
 
         Notes
         -----
         .. versionchanged:: 0.4.0
-            Calling signature has changed from the sync parameters 
+            Calling signature has changed from the sync parameters
             passed on as a list, to passed on as parameters.
         '''
         if len(parameters)<2:
@@ -1254,14 +1291,14 @@ class MultiDBD(object):
             else:
                 r.append(numpy.interp(t, _t, _v, left=numpy.nan, right=numpy.nan))
         return r
-    
+
     def get_list(self,*parameters,decimalLatLon=True, discardBadLatLon=True, return_nans=False):
         ''' Returns time and value tuples for a list of requested parameters
-        
+
 
         This method returns time and values tuples for a list of parameters. It
         is basically a short-hand for a looped get() method.
-        
+
         Note that each parameter comes with its own time base. No interpolation
         is done. Use get_sync() for that in stead.
 
@@ -1271,19 +1308,19 @@ class MultiDBD(object):
             list of parameter names
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         return_nans : bool
             If True, nan's are returned for those timestamps where no new value is available.
             Default value: False
 
         Returns
         -------
-        list of (ndarray, ndarray) 
+        list of (ndarray, ndarray)
             list of tuples of time and value vectors for each parameter requested.
 
         .. deprecated:: 0.4.0
@@ -1296,7 +1333,7 @@ class MultiDBD(object):
 
 
     def get_CTD_sync(self, *parameters, decimalLatLon=True, discardBadLatLon=True):
-        '''Returns a list of values from CTD and optionally other parameters, 
+        '''Returns a list of values from CTD and optionally other parameters,
         all interpolated to the time base of the CTD timestamp.
 
         Parameters
@@ -1305,16 +1342,16 @@ class MultiDBD(object):
             names of parameters to be read additionally
 
         decimalLatLon : bool, optional
-            If True (default), latitiude and longitude related parameters are converted to 
+            If True (default), latitiude and longitude related parameters are converted to
             decimal format, as opposed to nmea format.
 
         discardBadLatLon : bool, optional
             If True (default), bogus latitiude and longitude values are ignored.
-        
+
         Returns
         -------
         (ndarray, ndarray, ...)
-            Time vector (of first parameter), C, T and P values, and 
+            Time vector (of first parameter), C, T and P values, and
             interpolated values of subsequent parameters.
 
 
@@ -1351,24 +1388,25 @@ class MultiDBD(object):
         Returns
         -------
         bool
-            True if this instance has found parameter 
+            True if this instance has found parameter
         '''
         return (parameter in self.parameterNames['sci'] or parameter in self.parameterNames['eng'])
 
     @classmethod
     def isScienceDataFile(cls,fn):
         ''' Is file a science file?
-        
+
         Parameters
         ----------
         fn : str
             filename
-        
+
         Returns
         -------
         bool
             True if file fn is a science file
         '''
+        fn = fn.lower()
         return fn.endswith("ebd") | fn.endswith("tbd") | fn.endswith("nbd")
 
     def get_time_range(self,fmt="%d %b %Y %H:%M"):
@@ -1387,7 +1425,7 @@ class MultiDBD(object):
         return self.__get_time_range(self.time_limits,fmt)
 
     def get_global_time_range(self,fmt="%d %b %Y %H:%M"):
-        ''' Returns start and end dates of data set (all files) 
+        ''' Returns start and end dates of data set (all files)
 
         Parameters
         ----------
@@ -1444,7 +1482,7 @@ class MultiDBD(object):
             matchingExtension[1] = chr(ord(extension[1])+1)
         else:
             matchingExtension[1] = chr(ord(extension[1])-1)
-        matchingExtension = "".join(matchingExtension)    
+        matchingExtension = "".join(matchingExtension)
         matchingFn = fn.replace(extension,matchingExtension)
         return matchingFn
 
@@ -1455,7 +1493,7 @@ class MultiDBD(object):
             if os.path.exists(mfn):
                 to_add.append(mfn)
         self.filenames+=to_add
-            
+
     def __get_matching_dbd(self,fn):
         '''returns matching dbd object corresponding to fn. If fn is not in the current list
            of accepted dbds, then None is returned.'''
@@ -1473,9 +1511,9 @@ class MultiDBD(object):
         ''' prune all files in filelist.'''
         for tbr in filelist:
             self.filenames.remove(tbr)
-    
+
     def __prune_unmatched(self, cacheDir=None):
-        ''' prune all files which don't have a science/engineering partner 
+        ''' prune all files which don't have a science/engineering partner
             returns list of removed files.'''
         to_be_removed=[fn for fn in self.filenames if not self.__get_matching_dbd(fn)]
         self.__prune(to_be_removed, cacheDir)
@@ -1506,7 +1544,7 @@ class MultiDBD(object):
         time_limits_dataset = [1e10, 0]
         # min and max times of selected data set (can be None)
         time_limits = self.time_limits
-        
+
         # if no time_limits set, use all data.
         if not time_limits[0]:
             time_limits[0]=0
@@ -1522,7 +1560,7 @@ class MultiDBD(object):
                 time_limits_dataset[1]=t
             #
             if t<time_limits[0] or t>time_limits[1]:
-                self.__ignore_cache.append(dbd) 
+                self.__ignore_cache.append(dbd)
             else:
                 self.__accept_cache.append(dbd)
                 # this is a file that matches the selection criterion.
@@ -1549,7 +1587,15 @@ class MultiDBD(object):
         filenames=list(self.filenames)
         missing_cacheIDs = []
         for fn in self.filenames:
-            dbd=DBD(fn, cacheDir, raise_exception_if_cac_not_found=False)
+            try:
+                dbd=DBD(fn, cacheDir, raise_exception_if_cac_not_found=False)
+            except Exception as e:
+                logger.warning('File %s could not be loaded', fn)
+                logger.debug('Exception was %s', e)
+                filenames.remove(fn)
+                continue
+            else:
+                dbd.close()
             if not dbd.cacheFound:
                 missing_cacheIDs.append(dbd.cacheID) # add missing cacheId for and check later if we need it
             mission_name=dbd.get_mission_name()
@@ -1582,7 +1628,7 @@ class MultiDBD(object):
         if len(self.dbds['sci'])+len(self.dbds['eng'])==0:
             raise DbdError(DBD_ERROR_ALL_FILES_BANNED, " (Read %d files.)"%(len(self.filenames)))
         self.filenames=filenames
-    
+
     def __getParameterUnits(self):
         dbds=self.dbds['eng']
         units=[]
@@ -1609,10 +1655,10 @@ class MultiDBD(object):
         parameter_names.sort()
         return parameter_names
 
-                         
+
     def __worker(self,method,ft,*p,**kwds):
         # if i in __ignore_cache, the file is flagged as outside the time limits
-        #tmp=[eval("i.%s(*p)"%(method)) for i in self.dbds[ft] 
+        #tmp=[eval("i.%s(*p)"%(method)) for i in self.dbds[ft]
         #     if i not in self.__ignore_cache]
         data = dict([(k,[]) for k in p])
         error_mesgs = []
